# AgriGEE.lite

<!-- [![Release](https://img.shields.io/github/v/release/fpgmaas/cookiecutter-uv-example)](https://img.shields.io/github/v/release/fpgmaas/cookiecutter-uv-example)
[![Build status](https://img.shields.io/github/actions/workflow/status/fpgmaas/cookiecutter-uv-example/main.yml?branch=main)](https://github.com/fpgmaas/cookiecutter-uv-example/actions/workflows/main.yml?query=branch%3Amain)
[![Commit activity](https://img.shields.io/github/commit-activity/m/fpgmaas/cookiecutter-uv-example)](https://img.shields.io/github/commit-activity/m/fpgmaas/cookiecutter-uv-example)
[![License](https://img.shields.io/github/license/fpgmaas/cookiecutter-uv-example)](https://img.shields.io/github/license/fpgmaas/cookiecutter-uv-example)

This is a template repository for Python projects that use uv for their dependency management. -->
